NexFilePickerState class abstract
An abstract class to define the state handling for file picking operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
error(
dynamic error) → void - Called when an error occurs during the file picking process.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
success(
{ReturnModel? fileData, String? type}) → void - Called when a file is successfully picked.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited