error abstract method
void
error(
- dynamic error
Called when an error occurs during the file picking process.
error represents the error that occurred.
Implementation
void error(var error);
Called when an error occurs during the file picking process.
error represents the error that occurred.
void error(var error);